==> haskell-pipes-4.3.4-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.4
id: pipes-4.3.4-BvSd4URf0wlE2GikyprOR6
key: pipes-4.3.4-BvSd4URf0wlE2GikyprOR6
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: 0d15c56940702ca6768354b99fa684fb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/pipes-4.3.4
hs-libraries: HSpipes-4.3.4-BvSd4URf0wlE2GikyprOR6
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.4-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.4
id: pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH
key: pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: dd7bdcc973b454d52fa69bdf56d83d1c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pipes-4.3.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/pipes-4.3.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/pipes-4.3.4
hs-libraries: HSpipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH
depends:
    base-4.9.1.0 exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    void-0.7.2-2kaNlnbmZo5LCwbtPDXIQb
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
